==> solid-5.42.0.tar.xz: solid-5.42.0/src/solid/devices/backends/fakehw/fakecamera.h <==
/*
    Copyright 2006 Kevin Ottens <ervin@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKECAMERA_H
#define SOLID_BACKENDS_FAKEHW_FAKECAMERA_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/camera.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeCamera : public FakeDeviceInterface, virtual public Solid::Ifaces::Camera
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::Camera)

public:
    explicit FakeCamera(FakeDevice *device);
    ~FakeCamera();

public Q_SLOTS:
    QStringList supportedProtocols() const Q_DECL_OVERRIDE;
    QStringList supportedDrivers(QString protocol) const Q_DECL_OVERRIDE;
    QVariant driverHandle(const QString &driver) const Q_DECL_OVERRIDE;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKECAMERA_H

==> solid-5.59.0.tar.xz: solid-5.59.0/src/solid/devices/backends/fakehw/fakecamera.h <==
/*
    Copyright 2006 Kevin Ottens <ervin@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKECAMERA_H
#define SOLID_BACKENDS_FAKEHW_FAKECAMERA_H

#include "fakedeviceinterface.h"
#include <solid/devices/ifaces/camera.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeCamera : public FakeDeviceInterface, virtual public Solid::Ifaces::Camera
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::Camera)

public:
    explicit FakeCamera(FakeDevice *device);
    ~FakeCamera();

public Q_SLOTS:
    QStringList supportedProtocols() const override;
    QStringList supportedDrivers(QString protocol) const override;
    QVariant driverHandle(const QString &driver) const override;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKECAMERA_H
